=======================
Xml documents generator
=======================

.. image:: https://travis-ci.com/Vauxoo/cfdilib.svg?token=VAty1EWicYm2yKQxZptp&branch=master
    :target: https://travis-ci.com/Vauxoo/cfdilib


Library to xml documents based on XSD files to manage situations where you need to sign such
documents with a third party, then given a simple dictionary and a jinja2 template you will be
able to generate such documents with almos 0 logic..

* Free software: Vauxoo Licence
* Documentation: https://vauxoo.github.io/cfdilib

Features
--------

* TODO

Credits
---------

Designed by: Nhomar Hernández <nhomar@vauxoo.com>

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
